summaryrefslogtreecommitdiff
path: root/addons/website_livechat/i18n/fr.po
diff options
context:
space:
mode:
authorAdrian Torres <adt@odoo.com>2019-08-26 18:53:57 +0000
committerRaphael Collet <rco@odoo.com>2019-08-30 16:16:17 +0000
commit957c78b98f172cfb377acd0dbd707aeb3f83d4a9 (patch)
tree227d53d9fecbff6d849cf2847a2690e9df3e7d11 /addons/website_livechat/i18n/fr.po
parent3d0b42045f4d7f023411a29082ff506f3b257eea (diff)
[IMP] base: optimize create on models with property fields
Before this commit, creating a record of a model with at least one property/company_dependent field would trigger the field's inverse method regardless of whether an actual value was being passed in for the field or not. This means that if no value was given or if the value was the same as the default value, we would waste precious time in the property field's inverse method. With this commit, we do not call the inverse method if: 1) there is no value for it in the vals dict (use default) 2) the value in the vals dict is the same as the default value As an example, when creating a res.partner record while having account installed (which introduces a property field in res.partner), the creation time goes from 24ms to 14ms. closes odoo/odoo#36267 Signed-off-by: Raphael Collet (rco) <rco@openerp.com>
Diffstat (limited to 'addons/website_livechat/i18n/fr.po')
0 files changed, 0 insertions, 0 deletions